.. image:: ../LOGO/osf-cli-logo-v1.png
   :alt: osfclient
   :width: 200px
   :align: right

Welcome to osfclient's documentation!
=====================================

The ``osfclient`` is a python library and a command-line client for up-
and downloading files to and from your `Open Science Framework`_
projects. The *Open Science Framework* (OSF) is an open source project
which facilitates the open collaboration of researchers on the web, by
sharing data and other research outputs.

As such the OSF hosts large data sets, associated with papers or
scientific projects, that can be freely downloaded. The *osfclient*
allows people to store and retrieve large datasets associated to their
scientific projects and papers on the OSF via the command line
interface. If you are completely new to the OSF you can
read the `OSF introductory materials`_.

This is a very new project, it has some rough edges. You can find the code for
the ``osfclient`` in the `GitHub repository`_.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cli-usage
   api/osfclient


.. _Open Science Framework: https://osf.io
.. _OSF introductory materials: https://cos.io/our-products/open-science-framework/
.. _GitHub repository: https://github.com/dib-lab/osf-cli
